Crate grit_junk_drawer

Crate grit_junk_drawer 

Macros

chain_match
Recursively match one or more patterns, each with optional guard clauses, and resolve to the final expresion or statement if all matches succeed, else resolve to the previous default expression or statement