Crate grit_junk_drawer
grit_
junk_
drawer
0.0.5
All Items
Crate Items
Macros
Crate
grit_
junk_
drawer
Macros

chain_
match
Recursively match one or more patterns, each with optional guard clauses, and resolve to the final expresion or statement if all matches succeed, else resolve to the previous default expression or statement